# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from cms.models.pluginmodel import CMSPlugin

from easy_thumbnails.files import get_thumbnailer
from easy_thumbnails.exceptions import InvalidImageFormatError
from image_cropping import ImageRatioField
from imagekit.models import ProcessedImageField
from pilkit.processors import ResizeToFit


class CoverSettings(CMSPlugin):
    title = models.CharField(
        _("title"),
        max_length=255,
        blank=True, null=True,
    )
    subtitle = models.CharField(
        _("subtitle"),
        max_length=255,
        blank=True, null=True,
    )
    image = ProcessedImageField(
        processors=[ResizeToFit(width=900)],
        upload_to=settings.CMSMISC_COVER_SETTINGS_COVER_UPLOAD_TO,
        format='JPEG',
        options={'quality': 100},
        blank=True, null=True,
        verbose_name=_("image")
    )
    image_cropping = ImageRatioField(
        'image',
        '850x197',
        size_warning=True
    )

    @property
    def image_url(self):
        try:
            return get_thumbnailer(self.image).get_thumbnail({
                'size': (900, 197),
                'box': self.image_cropping,
                'crop': True,
                'detail': True,
            }).url
        except (InvalidImageFormatError, AttributeError):
            return ""

    def __unicode__(self):
        return self.title

    class Meta(object):
        verbose_name = _('Cover')
        verbose_name_plural = _('Covers')
        app_label = "cmsmisc"


class EmailSettings(CMSPlugin):
    title = models.CharField(
        _("title"),
        max_length=255,
        blank=True, null=True
    )
    template_name = models.CharField(
        max_length=255,
        choices=settings.CMSMISC_EMAIL_SETTINGS_TEMPLATE_NAME,
        default="cms_plugin/cms_plugins/email_template.html",
        help_text=_('Choose template render email plugin')
    )
    template_email_content = models.CharField(
        max_length=255,
        choices=settings.CMSMISC_EMAIL_SETTINGS_TEMPLATE_EMAIL_CONTENT,
        default="cmsmisc/cms_plugins/email_template_content.html",
        help_text=_('Choose template content email')
    )
    subject_email = models.CharField(
        _("subject email"),
        max_length=255,
    )
    from_email = models.EmailField(
        _("from email"),
        max_length=255,
    )

    def __unicode__(self):
        return u'AcomeA email'

    class Meta:
        app_label = "cmsmisc"
