# -*- coding: utf-8 -*-

from django.core.mail import EmailMultiAlternatives
from django.template import Context
from django.template.loader import get_template
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from image_cropping import ImageCroppingMixin

from . import forms, models


class CoverPlugin(ImageCroppingMixin, CMSPluginBase):
    model = models.CoverSettings
    name = _("Cover plugin")
    module = _("AcomeA Custom Plugin")
    admin_preview = False
    render_template = "cmsmisc/cms_plugins/title_template.html"

    def render(self, context, instance, placeholder):
        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


class EmailPlugin(CMSPluginBase):
    model = models.EmailSettings
    name = _("Email plugin")
    module = _("AcomeA Custom Plugin")
    admin_preview = False

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user

        if request.method == 'POST' and 'acomea_email_{}'.format(instance.id) in request.POST:
            send_email_form = forms.SendMail(request.POST)
            if send_email_form.is_valid():
                # mail field
                to = send_email_form.cleaned_data['email']
                link_url = send_email_form.cleaned_data['url_page']
                subject = instance.subject_email
                from_email = instance.from_email
                # mail message
                context_email_tamplate = Context({
                    'user': request.user,
                    'link': link_url
                })
                plaintext = get_template('{}.{}'.format(instance.template_email_content, 'txt'))
                htmly = get_template('{}.{}'.format(instance.template_email_content, 'html'))
                text_content = plaintext.render(context_email_tamplate)
                html_content = htmly.render(context_email_tamplate)

                # send mail
                msg = EmailMultiAlternatives(subject, text_content, from_email, [to])
                msg.attach_alternative(html_content, "text/html")
                msg.send()
                context.update({'email_message': u'Abbiamo inviato un memo alla email {0}'.format(to)})
            else:
                # Aggiungo l'errore anche con chiave email_message per renderlo disp. al resto della pagina
                context.update({'email_message': send_email_form.errors})
        # GET
        else:
            if user.is_authenticated():
                send_email_form = forms.SendMail(initial={'email': user.email})
            else:
                send_email_form = forms.SendMail()

        self.render_template = instance.template_name
        context.update({
            'send_email_form': send_email_form,
            'instance': instance,
            'placeholder': placeholder,
        })
        return context

plugin_pool.register_plugin(CoverPlugin)
plugin_pool.register_plugin(EmailPlugin)
